
package Data::Feed::Item;
use Any::Moose '::Role';

no Any::Moose '::Role';

1;

__END__

=head1 NAME

Data::Feed::Item - An Item In a Feed

=cut
